There are a few places that use these values, so define constants for
them.

Signed-off-by: Michael Haggerty <mhag...@alum.mit.edu>
---
If I were confident that it would always be inlined, I would have
used

    #define LOCK_SUFFIX_LEN strlen(LOCK_SUFFIX)

Or maybe even have omitted this constant and write strlen(LOCK_SUFFIX)
inline where it is needed instead.  But I'm not so I didn't.

It's possible I missed other code that uses ".lock" or the magic
number 5, but these are the only ones I found.

 cache.h    |  4 ++++
 lockfile.c | 12 ++++++------
 refs.c     |  7 ++++---
 3 files changed, 14 insertions(+), 9 deletions(-)

diff --git a/cache.h b/cache.h
index 3a873a4..825cd0a 100644
--- a/cache.h
+++ b/cache.h
@@ -533,6 +533,10 @@ extern void fill_stat_cache_info(struct cache_entry *ce, 
struct stat *st);
 #define REFRESH_IN_PORCELAIN   0x0020  /* user friendly output, not "needs 
update" */
 extern int refresh_index(struct index_state *, unsigned int flags, const 
struct pathspec *pathspec, char *seen, const char *header_msg);
 
+/* String appended to a filename to derive the lockfile name: */
+#define LOCK_SUFFIX ".lock"
+#define LOCK_SUFFIX_LEN 5
+
 struct lock_file {
        struct lock_file *next;
        int fd;
diff --git a/refs.c b/refs.c
index 67fe8b7..2805b31 100644
--- a/refs.c
+++ b/refs.c
@@ -63,7 +63,8 @@ static int check_refname_component(const char *refname, int 
flags)
                if (refname[1] == '\0')
                        return -1; /* Component equals ".". */
        }
-       if (cp - refname >= 5 && !memcmp(cp - 5, ".lock", 5))
+       if (cp - refname >= LOCK_SUFFIX_LEN &&
+           !memcmp(cp - LOCK_SUFFIX_LEN, LOCK_SUFFIX, LOCK_SUFFIX_LEN))
                return -1; /* Refname ends with ".lock". */
        return cp - refname;
 }
@@ -2486,11 +2487,11 @@ static int delete_ref_loose(struct ref_lock *lock, int 
flag)
 {
        if (!(flag & REF_ISPACKED) || flag & REF_ISSYMREF) {
                /* loose */
-               int err, i = strlen(lock->lk->filename) - 5; /* .lock */
+               int err, i = strlen(lock->lk->filename) - LOCK_SUFFIX_LEN;
 
                lock->lk->filename[i] = 0;
                err = unlink_or_warn(lock->lk->filename);
-               lock->lk->filename[i] = '.';
+               lock->lk->filename[i] = LOCK_SUFFIX[0];
                if (err && errno != ENOENT)
                        return 1;
        }
diff --git a/lockfile.c b/lockfile.c
index 8f6652c..1ce0e87 100644
--- a/lockfile.c
+++ b/lockfile.c
@@ -172,14 +172,14 @@ static char *resolve_symlink(char *p, size_t s)
        return p;
 }
 
-
 static int lock_file(struct lock_file *lk, const char *path, int flags)
 {
        /*
         * subtract 5 from size to make sure there's room for adding
         * ".lock" for the lock file name
         */
-       static const size_t max_path_len = sizeof(lk->filename) - 5;
+       static const size_t max_path_len = sizeof(lk->filename) -
+                                          LOCK_SUFFIX_LEN;
 
        if (!lock_file_list) {
                /* One-time initialization */
@@ -202,7 +202,7 @@ static int lock_file(struct lock_file *lk, const char 
*path, int flags)
        strcpy(lk->filename, path);
        if (!(flags & LOCK_NODEREF))
                resolve_symlink(lk->filename, max_path_len);
-       strcat(lk->filename, ".lock");
+       strcat(lk->filename, LOCK_SUFFIX);
        lk->fd = open(lk->filename, O_RDWR | O_CREAT | O_EXCL, 0666);
        if (0 <= lk->fd) {
                lk->owner = getpid();
@@ -296,7 +296,7 @@ int commit_lock_file(struct lock_file *lk)
        if (lk->fd >= 0 && close_lock_file(lk))
                return -1;
        strcpy(result_file, lk->filename);
-       i = strlen(result_file) - 5; /* .lock */
+       i = strlen(result_file) - LOCK_SUFFIX_LEN; /* .lock */
        result_file[i] = 0;
        if (rename(lk->filename, result_file))
                return -1;
@@ -172,14 +172,14 @@ static char *resolve_symlink(char *p, size_t s)
 {
        /*
-        * subtract 5 from size to make sure there's room for adding
-        * ".lock" for the lock file name
+        * subtract LOCK_SUFFIX_LEN from size to make sure there's
+        * room for adding ".lock" for the lock file name:
         */
-- 
1.9.1

--
To unsubscribe from this list: send the line "unsubscribe git" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to